@@ -35,6 +35,7 @@ GtkTreeStore *store = NULL;
   GtkWidget *rbDriverOR;
   GtkWidget *rbDriverHA;
   GtkWidget *rbDriverSC;
+  GtkWidget *rbDriverCI;
   GtkWidget *cbDevice;
   GtkWidget *lpsum;
   GtkWidget *lpdata;
@@ -172,7 +173,6 @@ create_fMain (void)
   /* main toolbar */
   toolbar = gtk_toolbar_new();
   gtk_toolbar_set_icon_size(GTK_TOOLBAR(toolbar),GTK_ICON_SIZE_SMALL_TOOLBAR);
-  gtk_toolbar_set_style(GTK_TOOLBAR(toolbar),GTK_TOOLBAR_ICONS);
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
 			       GTK_ORIENTATION_HORIZONTAL);  
   gtk_box_pack_start(GTK_BOX(vbox1),toolbar, FALSE, TRUE, 0);
@@ -191,7 +191,6 @@ create_fMain (void)
   gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
   gtk_toolbar_insert_stock(GTK_TOOLBAR(toolbar),GTK_STOCK_QUIT,_("Exit"),
   	NULL,(GtkSignalFunc)on_fMain_destroy,NULL,-1);
-  
 
   notebook1 = gtk_notebook_new ();
   gtk_box_pack_start (GTK_BOX (vbox1), notebook1, TRUE, TRUE, 0);
@@ -213,7 +212,7 @@ create_fMain (void)
   gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), tw);
   gtk_label_set_justify (GTK_LABEL (tw), GTK_JUSTIFY_LEFT);
   
-	/* init tree storage stuff */
+  /* init tree storage stuff */
 	store = gtk_tree_store_new (N_COLUMNS,
 				    G_TYPE_OBJECT,
 				    G_TYPE_STRING,
@@ -234,10 +233,7 @@ create_fMain (void)
 		g_signal_connect (G_OBJECT (tree), "cursor-changed",
 				  G_CALLBACK (tv_row_clicked), NULL);
 
-/*  gtk_signal_connect (GTK_OBJECT (tree), "row-activated",
-                      GTK_SIGNAL_FUNC (on_tree_select_row),
-                      NULL);
-*/		renderer = gtk_cell_renderer_pixbuf_new ();
+		renderer = gtk_cell_renderer_pixbuf_new ();
 		column = gtk_tree_view_column_new_with_attributes (_("IC"),
 								   renderer,
 								   "pixbuf",
@@ -329,7 +325,6 @@ create_fMain (void)
   gtk_table_attach (GTK_TABLE (table1), label25, 0, 2, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (label25), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (label25), 0, 0.5);
   gtk_misc_set_padding (GTK_MISC (label25), 3, 0);
 
@@ -338,7 +333,6 @@ create_fMain (void)
   gtk_table_attach (GTK_TABLE (table1), label24, 0, 1, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (label24), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (label24), 0, 0.5);
   gtk_misc_set_padding (GTK_MISC (label24), 3, 0);
 
@@ -347,7 +341,6 @@ create_fMain (void)
   gtk_table_attach (GTK_TABLE (table1), label26, 2, 3, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (label26), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (label26), 0, 0.5);
   gtk_misc_set_padding (GTK_MISC (label26), 3, 0);
 
@@ -356,7 +349,6 @@ create_fMain (void)
   gtk_table_attach (GTK_TABLE (table1), label28, 0, 1, 2, 3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (label28), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (label28), 0, 0.5);
   gtk_misc_set_padding (GTK_MISC (label28), 3, 0);
 
@@ -365,43 +357,38 @@ create_fMain (void)
   gtk_table_attach (GTK_TABLE (table1), label29, 2, 3, 2, 3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (label29), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (label29), 0, 0.5);
   gtk_misc_set_padding (GTK_MISC (label29), 3, 0);
 
   lpdata = gtk_label_new (_("0"));
   gtk_widget_show (lpdata);
   gtk_table_attach (GTK_TABLE (table1), lpdata, 1, 2, 1, 2,
-                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (lpdata), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (lpdata), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (lpdata), 3, 0);
 
   lpiiv = gtk_label_new (_("0"));
   gtk_widget_show (lpiiv);
   gtk_table_attach (GTK_TABLE (table1), lpiiv, 3, 4, 1, 2,
-                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (lpiiv), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (lpiiv), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (lpiiv), 3, 0);
 
   llong = gtk_label_new ("-");
   gtk_widget_show (llong);
   gtk_table_attach (GTK_TABLE (table1), llong, 1, 2, 2, 3,
-                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (llong), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (llong), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (llong), 3, 0);
 
   llat = gtk_label_new ("-");
   gtk_widget_show (llat);
   gtk_table_attach (GTK_TABLE (table1), llat, 3, 4, 2, 3,
-                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (llat), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (llat), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (llat), 3, 0);
 
@@ -410,7 +397,6 @@ create_fMain (void)
   gtk_table_attach (GTK_TABLE (table1), lpsum, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-  gtk_label_set_justify (GTK_LABEL (lpsum), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (lpsum), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (lpsum), 3, 0);
 
@@ -437,50 +423,48 @@ create_fMain (void)
   gtk_label_set_markup(GTK_LABEL(lConfig),"<b>Scanner Controls</b>");
   gtk_box_pack_start (GTK_BOX (vbox3), lConfig, FALSE, FALSE, 0);
 
-  cbNight = gtk_check_button_new_with_label (_("night design"));
+  cbNight = gtk_check_button_new_with_label (_("Night Design"));
   gtk_widget_show (cbNight);
-  gtk_box_pack_start (GTK_BOX (vbox3), cbNight, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox3), cbNight, TRUE, TRUE, 0);
   gtk_widget_set_usize (cbNight, 99, 24);
 
-  rbCAll = gtk_radio_button_new_with_label (rgc_group, _("all channels"));
+  rbCAll = gtk_radio_button_new_with_label (rgc_group, _("All Channels"));
   rgc_group = gtk_radio_button_group (GTK_RADIO_BUTTON (rbCAll));
   gtk_widget_show (rbCAll);
-  gtk_box_pack_start (GTK_BOX (vbox3), rbCAll, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox3), rbCAll, TRUE, TRUE, 0);
   gtk_widget_set_usize (rbCAll, 93, 24);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rbCAll), TRUE);
 
   hbox2 = gtk_hbox_new (FALSE, 0);
   gtk_widget_show (hbox2);
-  gtk_box_pack_start (GTK_BOX (vbox3), hbox2, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox3), hbox2, TRUE, TRUE, 0);
 
-  rbCSpecific = gtk_radio_button_new_with_label (rgc_group, _("specific channel"));
+  rbCSpecific = gtk_radio_button_new_with_label (rgc_group, _("Specific Channel"));
   rgc_group = gtk_radio_button_group (GTK_RADIO_BUTTON (rbCSpecific));
   gtk_widget_show (rbCSpecific);
-  gtk_box_pack_start (GTK_BOX (hbox2), rbCSpecific, FALSE, FALSE, 0);
-  gtk_widget_set_usize (rbCSpecific, -2, 16);
-
+  gtk_box_pack_start (GTK_BOX (hbox2), rbCSpecific, FALSE, TRUE, 0);
+ 
   eSChannel = gtk_spin_button_new_with_range(1.0,14.0,1);
   gtk_widget_show (eSChannel);
   gtk_box_pack_start (GTK_BOX (hbox2), eSChannel, FALSE, TRUE, 3);
-  gtk_widget_set_usize (eSChannel, 30, 20);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(eSChannel),1.0);
 
-  cbFakeAP = gtk_check_button_new_with_label (_("fake ap filter"));
+  cbFakeAP = gtk_check_button_new_with_label (_("Fake AP Filter"));
   gtk_widget_show (cbFakeAP);
-  gtk_box_pack_start (GTK_BOX (vbox3), cbFakeAP, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox3), cbFakeAP, TRUE, TRUE, 0);
 
   hbox3 = gtk_hbox_new (FALSE, 0);
   gtk_widget_show (hbox3);
-  gtk_box_pack_start (GTK_BOX (vbox3), hbox3, FALSE, TRUE, 0);  
+  gtk_box_pack_start (GTK_BOX (vbox3), hbox3, TRUE, TRUE, 0);  
   
   hbox3 = gtk_hbox_new (FALSE, 0);
   gtk_widget_show (hbox3);
   gtk_box_pack_start (GTK_BOX (vbox3), hbox3, FALSE, FALSE, 0);
 
-  label39 = gtk_label_new (_("Capture\ndevice"));
+  label39 = gtk_label_new (_("Capture\nDevice"));
   gtk_misc_set_padding (GTK_MISC (label39), 3, 0);
   gtk_widget_show (label39);
-  gtk_box_pack_start (GTK_BOX (hbox3), label39, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox3), label39, FALSE, TRUE, 0);
   gtk_label_set_justify (GTK_LABEL (label39), GTK_JUSTIFY_LEFT);
   gtk_label_set_line_wrap (GTK_LABEL (label39), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label39), 0, 0.1);
@@ -490,7 +474,6 @@ create_fMain (void)
   gtk_widget_set_size_request(cbDevice,60,-1);
   gtk_widget_show (cbDevice);
   gtk_box_pack_start (GTK_BOX (hbox3), cbDevice, FALSE, TRUE, 3);
-  gtk_container_set_border_width (GTK_CONTAINER (cbDevice), 3);
 
   eDevice = GTK_COMBO (cbDevice)->entry;
   gtk_widget_show (eDevice);
@@ -499,13 +482,13 @@ create_fMain (void)
 
   label40 = gtk_label_new (_("Driver type"));
   gtk_widget_show (label40);
-  gtk_box_pack_start (GTK_BOX (vbox3), label40, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox3), label40, TRUE, TRUE, 0);
   gtk_misc_set_alignment (GTK_MISC (label40), 0, 0.5);
   gtk_misc_set_padding (GTK_MISC (label40), 3, 3);
 
   hbox4 = gtk_hbox_new (FALSE, 0);
   gtk_widget_show (hbox4);
-  gtk_box_pack_start (GTK_BOX (vbox3), hbox4, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox3), hbox4, TRUE, TRUE, 0);
 
   rbDriverOR = gtk_radio_button_new_with_label (hbox4_group, _("Orinoco"));
   hbox4_group = gtk_radio_button_group (GTK_RADIO_BUTTON (rbDriverOR));
@@ -525,8 +508,6 @@ create_fMain (void)
   gtk_widget_show (rbDriverSC);
   gtk_box_pack_start (GTK_BOX (hbox4), rbDriverSC, FALSE, FALSE, 1);
   
-  bStartScan = gtk_button_new_from_stock(GTK_STOCK_APPLY);
-  
 #ifdef WLAN_NG
   rbDriverNG = gtk_radio_button_new_with_label (hbox4_group, _("Wl. NG"));
   hbox4_group = gtk_radio_button_group (GTK_RADIO_BUTTON (rbDriverNG));
@@ -534,8 +515,15 @@ create_fMain (void)
   gtk_box_pack_start (GTK_BOX (hbox4), rbDriverNG, FALSE, FALSE, 1);
 #endif
 
+  rbDriverCI = gtk_radio_button_new_with_label (hbox4_group, _("Cisco"));
+  hbox4_group = gtk_radio_button_group (GTK_RADIO_BUTTON (rbDriverCI));
+  
+  gtk_widget_show (rbDriverCI);
+  gtk_box_pack_start (GTK_BOX (hbox4), rbDriverCI, FALSE, FALSE, 1);
+  
+  bStartScan = gtk_button_new_from_stock(GTK_STOCK_APPLY);
   gtk_widget_show (bStartScan);
-  gtk_box_pack_start (GTK_BOX (vbox3), bStartScan, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (vbox3), bStartScan, FALSE, FALSE, 0);
 
   label4 = gtk_label_new (_("Control"));
   
@@ -593,7 +581,8 @@ create_fMain (void)
 
   label38 = gtk_label_new (_("Status"));
   gtk_widget_show (label38);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 3), label38);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), 
+  	gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 3), label38);
 
   gpbSignal = gtk_progress_bar_new ();
   gtk_widget_show (gpbSignal);
@@ -634,6 +623,10 @@ create_fMain (void)
   gtk_signal_connect_after (GTK_OBJECT(eSChannel),"change-value", 
                       GTK_SIGNAL_FUNC(on_eSChannel_value_changed),NULL);
 					  
+  g_signal_connect (G_OBJECT (tree), "button-press-event",
+                            G_CALLBACK (on_gclWlans_button_press_event),
+                            NULL);
+							
   /* set signal gauge color */
 	astyle = gtk_widget_get_style (gpbSignal);
 	rc_style = gtk_rc_style_new ();
@@ -663,6 +656,7 @@ create_fMain (void)
   return fMain;
 }
 
+
 GtkWidget*
 create_menu1 (void)
 {
