@@ -29,6 +29,7 @@
  */
 
 #define _XOPEN_SOURCE
+#define _XOPEN_SOURCE_EXTENDED
 
 #include <unistd.h>
 #include <string.h>
@@ -44,13 +45,15 @@
 #include <sys/stat.h>
 #include <sys/file.h>
 #include <errno.h>
+#include <ctype.h>
+#include <glib.h>
 
 #include "prismstumbler.h"
 #include "fxgps.h"
 #include "analyzer.h"
 #include "iface-scan.h"
 #include "iface-wlan-14.h"
-
+#include "cards.h"
 
 /*
  * How many packet should we read if we have a signal on a channel????
@@ -147,19 +150,6 @@ send_config (int sock)
 }
 
 
-static void
-send_net (int pos, int sock)
-{
-	psmessage_t msg;
-	msg.type = msg_network;
-	msg.content.net = *netlist[pos];
-	if (write (sock, (void *) &msg, sizeof (psmessage_t)) < 0)
-	{
-		perror ("err sending stream data");
-	}
-}
-
-
 void
 send_netlist (int sock, int all)
 {
@@ -240,6 +230,34 @@ net_check_connection()
 }
 
 
+/* bring down the configured interface 
+ * useful helper function for frontends 
+ */
+void
+do_interface_down(void)
+{
+	char syscmd[128];
+	FILE *idf;
+	
+	snprintf (syscmd, 127, "/sbin/ifconfig %s down", cfg.device);
+	system(syscmd);
+	/* check if we are on a HP h5xxx device*/
+	if (!access("/proc/hal/model",R_OK))
+	{
+		if ((idf = fopen("/proc/hal/model","r")))
+		{
+			fscanf(idf,"%10s",syscmd);
+			fclose(idf);
+			if (strstr(syscmd,"5400"))
+			{
+				snprintf (syscmd, 127, "/sbin/rmmod at76c503-rfmd usbvnetr");
+				system(syscmd);
+			}
+		}
+	}
+}
+
+
 /* try to connect to a given wireless lan */
 static int
 net_associate (int seqnr, int sock)
@@ -255,7 +273,7 @@ net_associate (int seqnr, int sock)
 		shutCard ();
 	}
 
-	sprintf (syscmd, "ifconfig %s up", cfg.device);
+	sprintf (syscmd, "/sbin/ifconfig %s up", cfg.device);
 #ifdef DEBUG
 	printf ("exec: %s\n", syscmd);
 #endif
@@ -268,39 +286,39 @@ net_associate (int seqnr, int sock)
 #endif
 		if (usernet.mode) // ad-hoc
 		{
-			sprintf (syscmd, "iwconfig %s mode ad-hoc",
+			sprintf (syscmd, "/sbin/iwconfig %s mode ad-hoc",
 				 cfg.device);
 			system (syscmd);
-			sprintf (syscmd, "iwconfig %s channel %d", cfg.device,
+			sprintf (syscmd, "/sbin/iwconfig %s channel %d", cfg.device,
 				 usernet.channel);
 			system (syscmd);
-			sprintf (syscmd, "iwconfig %s essid %s", cfg.device,
+			sprintf (syscmd, "/sbin/iwconfig %s essid %s", cfg.device,
 				 usernet.ssid);
 			system (syscmd);
 		}
 		else		// managed
 		{
-			sprintf (syscmd, "iwconfig %s mode managed",
+			sprintf (syscmd, "/sbin/iwconfig %s mode managed",
 				 cfg.device);
 			system (syscmd);
-			sprintf (syscmd, "iwconfig %s essid %s", cfg.device,
+			sprintf (syscmd, "/sbin/iwconfig %s essid %s", cfg.device,
 				 usernet.ssid);
 			system (syscmd);
 		}
 		if (usernet.wep)
 		{
-			sprintf (syscmd, "iwconfig %s key %s", cfg.device, usernet.wep_key);
+			sprintf (syscmd, "/sbin/iwconfig %s key %s", cfg.device, usernet.wep_key);
 			system (syscmd);
 		}
 		/* in the case that we have no ip set, we use dhcp too */
 		if ((usernet.dhcp) || !usernet.ip[0]) 
 		{
-			sprintf (syscmd, DHCP_COMMAND, cfg.device);
+			sprintf (syscmd, dhcpcommands[cfg.dhcpcommand], cfg.device);
 			system (syscmd);
 		}
 		else
 		{
-			sprintf (syscmd, "ifconfig %s %d.%d.%d.%d netmask %d.%d.%d.%d", cfg.device, usernet.ip[0],usernet.ip[1],usernet.ip[2],usernet.ip[3],
+			sprintf (syscmd, "/sbin/ifconfig %s %d.%d.%d.%d netmask %d.%d.%d.%d", cfg.device, usernet.ip[0],usernet.ip[1],usernet.ip[2],usernet.ip[3],
 			usernet.netmask[0],usernet.netmask[1],usernet.netmask[2],usernet.netmask[3]);
 			system (syscmd);
 			sprintf (syscmd, "route del default");
@@ -322,28 +340,28 @@ net_associate (int seqnr, int sock)
 	{
 		if (netlist[seqnr]->isadhoc)  // ad-hoc mode
 		{
-			sprintf (syscmd, "iwconfig %s mode ad-hoc",
+			sprintf (syscmd, "/sbin/iwconfig %s mode ad-hoc",
 				 cfg.device);
 			system (syscmd);
-			sprintf (syscmd, "iwconfig %s channel %d", cfg.device,
+			sprintf (syscmd, "/sbin/iwconfig %s channel %d", cfg.device,
 				 netlist[seqnr]->channel);
 			system (syscmd);
-			sprintf (syscmd, "iwconfig %s essid %s", cfg.device,
+			sprintf (syscmd, "/sbin/iwconfig %s essid %s", cfg.device,
 				 netlist[seqnr]->ssid);
 			system (syscmd);
 		}
 		else		// managed
 		{
-			sprintf (syscmd, "iwconfig %s mode managed",
+			sprintf (syscmd, "/sbin/iwconfig %s mode managed",
 				 cfg.device);
 			system (syscmd);
-			sprintf (syscmd, "iwconfig %s essid %s", cfg.device,
+			sprintf (syscmd, "/sbin/iwconfig %s essid %s", cfg.device,
 				 netlist[seqnr]->ssid);
 			system (syscmd);
 		}
 		if (netlist[seqnr]->dhcp)
 		{
-			sprintf (syscmd, DHCP_COMMAND, cfg.device);
+			sprintf (syscmd, dhcpcommands[cfg.dhcpcommand], cfg.device);
 			system (syscmd);
 		}
 	}
@@ -373,6 +391,7 @@ detect_driver (int sock)
 	char dev_hostap[20];
 	char dev_orinoco[20];
 	char dev_prism[20];
+	char dev_cisco[20];
 	
 	sprintf (device, "none");
 	old_devtype = cfg.devtype;
@@ -432,6 +451,11 @@ detect_driver (int sock)
 					have_driver += DT_PRISM;
 					sprintf (dev_prism, "%s", d);
 				}
+				if (strstr (drv, "airo"))
+				{
+					have_driver += DT_CISCO;
+					sprintf (dev_cisco, "%s", d);
+				}
 				if (!strcmp (cfg.device, d))
 				{
 					i = 3;
@@ -488,6 +512,12 @@ detect_driver (int sock)
 		known = TRUE;
 	}
 	
+	if (strstr (drv, "airo"))
+	{
+		cfg.devtype = DT_CISCO;
+		known = TRUE;
+	}
+	
 	if (known)
 	{
 		if (RawSock >= 0)
@@ -528,6 +558,11 @@ detect_driver (int sock)
 				cfg.devtype = DT_HOSTAP;
 				snprintf (cfg.device, 6, "%s", dev_hostap);
 			}
+			if (have_driver & DT_CISCO)
+			{
+				cfg.devtype = DT_CISCO;
+				snprintf (cfg.device, 6, "%s", dev_cisco);
+			}
 #ifdef DEBUG
 			printf ("autoselected interface: %s\n", cfg.device);
 #endif			
@@ -551,33 +586,35 @@ detect_driver (int sock)
 			}
 			return TRUE;
 		}
+
 		else	/* probe scan on default devices */
-#warning todo: detect existing interfaces
 		{
-			if (do_scan_interface("wlan0", sock, 0.0, 0.0))
+			int found_sc = FALSE;
+			
+			GSList *iter, *devs = find_wireless_cards();
+			
+			for (iter = devs; iter; iter = iter->next)
 			{
-				cfg.devtype = DT_SCAN;
-				sprintf(cfg.device,"wlan0");
+				struct ps_card *c = (struct ps_card*)iter->data;
+				printf("scanning %s\n",c->name);
+				if (do_scan_interface(c->name, sock, 0.0, 0.0))
+				{
+					cfg.devtype = DT_SCAN;
+					sprintf(cfg.device, c->name);
+					found_sc = TRUE;
+					break;
+				}
 			}
-			else
-			if (do_scan_interface("wlan1", sock, 0.0, 0.0))
+			for (iter = devs; iter; iter = iter->next)
 			{
-				cfg.devtype = DT_SCAN;
-				sprintf(cfg.device,"wlan1");
+				struct ps_card *c = (struct ps_card*)iter->data;
+				g_free(c->name);
+				g_free(c->type);
 			}
-			else
-			if (do_scan_interface("eth0", sock, 0.0, 0.0))
-			{
-				cfg.devtype = DT_SCAN;
-				sprintf(cfg.device,"eth0");
-			}
-			else
-			if (do_scan_interface("eth1", sock, 0.0, 0.0))
-			{
-				cfg.devtype = DT_SCAN;
-				sprintf(cfg.device,"eth1");
-			}
-			else
+			g_slist_free(devs);
+			if (found_sc) 
+				return TRUE;
+			else /* now we really lost... */
 			{
 				// tell client that no card was detected
 				send_info(I_NOCARD,
@@ -796,7 +833,6 @@ update_config (psconfig_t * ncfg, int ps_socket)
 		}
 	}
 
-
 	/* scanner turned on, device changed, driver changed */
 	if ((ncfg->scan) || (strcmp (ncfg->device, cfg.device))
 	    || (ncfg->devtype != cfg.devtype))
@@ -812,6 +848,12 @@ update_config (psconfig_t * ncfg, int ps_socket)
 		cfg.devtype = ncfg->devtype;
 		cfg.scan = ncfg->scan;
 				
+		if ((RawSock = openPacket ()) < 0)
+		{
+			fprintf (stderr,"Can't open pcap device: %s",
+				 strerror (errno));
+			cfg.scan = FALSE;
+		}
 		if (cfg.devtype == DT_SCAN)
 		{
 			/* check scan mode, do single scan */
@@ -831,6 +873,7 @@ update_config (psconfig_t * ncfg, int ps_socket)
 					 strerror (errno));
 				cfg.scan = FALSE;
 			}
+			scan_avail = TRUE;
 		}
 	}
 	else
@@ -840,8 +883,11 @@ update_config (psconfig_t * ncfg, int ps_socket)
 	
 	cfg.delay = ncfg->delay;
 
-	if (cfg.scan && !RawSock)
+	if (cfg.scan && (RawSock<0) && (cfg.devtype != DT_SCAN))
+	{
 		RawSock = openPacket();
+		scan_avail = (RawSock >= 0);
+	}
 	
 	cfg.filter = ncfg->filter;
 	cfg.singlechan = ncfg->singlechan;
@@ -879,8 +925,26 @@ update_config (psconfig_t * ncfg, int ps_socket)
 		if (cfg.dumpfile[0])
 			pcap_start_dump();
 	}
+	cfg.dhcpcommand = ncfg->dhcpcommand;
 }
 
+int
+detect_dhcp(void)
+{
+	int i;
+	char binary[128] = {0};
+	
+	for (i=0; i < DHCP_CMDCOUNT; i++)
+	{
+		sscanf(dhcpcommands[i], "%128s", binary);
+		if (!access(binary, X_OK))
+		{
+			cfg.dhcpcommand = i;
+			return TRUE;
+		}
+	}
+	return 0;
+}
 
 void
 do_command (pscommand_t * cmd, int sock)
@@ -903,6 +967,13 @@ do_command (pscommand_t * cmd, int sock)
 	case C_GPSD:
 		do_initgps(sock);
 		break;	
+	case C_IFDOWN:
+		do_interface_down();
+		break;	
+	case C_DETECT_DHCP:
+		if (detect_dhcp ())
+			send_config (sock);
+		break;
 	default:
 		fprintf (stderr, "Received unknown command.\n");
 		break;
@@ -977,7 +1048,7 @@ psmain (int ps_socket)
 	static float Long, Lat, long_old, lat_old;
 	int scount = 1;
 
-	/* do some nasty things */
+	/* do some nasty things, dhcpcd will bring down our interface */
 	system("/usr/bin/killall dhcpcd > /dev/null 2>&1");
 	
 	/* set usernet data invalid */
@@ -990,10 +1061,10 @@ psmain (int ps_socket)
 	
 	RawSock = openPacket ();
 
-	while ((RawSock < 0) && !stop_sniffing)
+	while ((RawSock < 0) && !stop_sniffing && (!scan_avail))
 	{
 #ifdef DEBUG
-		perror ("Can't open pcap device, waiting for config\n");
+		perror ("Waiting for config\n");
 #endif
 		sleep (1);
 		if (check_messages (ps_socket) == -1)
