@@ -2,7 +2,7 @@
  * prismstumbler wireless lan analyzing tool
  *
  * Copyright (C) 2000 and created by Jan Fernquist  <Jan.B.Fernquist@telia.com>
- * Copyright (C) 2003 Florian Boor <florian.boor@kernelconcepts.de>
+ * Copyright (C) 2003, 2004 Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -60,6 +60,7 @@ extern GtkWidget *rbDriverNG;
 extern GtkWidget *rbDriverOR;
 extern GtkWidget *rbDriverHA;
 extern GtkWidget *rbDriverSC;
+extern GtkWidget *rbDriverCI;
 extern GtkWidget *lpsum;
 extern GtkWidget *lpdata;
 extern GtkWidget *lpiiv;
@@ -90,7 +91,7 @@ static guint last_row = 0;
 static void stop_signal ();
 void update_gui_pos(int netpos);
 static void update_config (psconfig_t * ncfg);
-static gboolean gui_update_busy = FALSE;
+static gboolean gui_update_busy = TRUE;
 static gboolean active_jump_to = FALSE;
 gboolean night_mode = FALSE;
 
@@ -260,10 +261,20 @@ load_icons (void)
 		gdk_pixbuf_new_from_file (PREFIX "/share/pixmaps/wlan-net.png",&err);
 	if (node_icons[N_NET])
 		gdk_pixbuf_ref (node_icons[N_NET]);
+	if (err)
+	{
+		g_error_free(err);
+		err = NULL;
+	}
 	node_icons[N_ADHOC] =
 		gdk_pixbuf_new_from_file (PREFIX "/share/pixmaps/miniwave-icon.png",&err);
 	if (node_icons[N_ADHOC])
 		gdk_pixbuf_ref (node_icons[N_ADHOC]);
+	if (err)
+	{
+		g_error_free(err);
+		err = NULL;
+	}
 }
 
 
@@ -322,6 +333,9 @@ update_config (psconfig_t * ncfg)
 	case DT_HOSTAP:
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rbDriverHA), TRUE);
 	break;
+	case DT_CISCO:
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rbDriverCI), TRUE);
+	break;
 #ifdef WLAN_NG
 	case DT_PRISM:
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rbDriverNG), TRUE);
@@ -398,9 +412,7 @@ do_try_connect (GtkWidget * w)
 	if (active_row < 0) return;
 		
 	/* we need to switch the scanner off */
-	on_toggle_scanner_clicked(NULL,NULL);
-//	cfg.scan = FALSE;
-//	send_config();
+	if (cfg.scan) on_toggle_scanner_clicked(NULL,NULL);
 	update_scannerbutton();
 	
 	usernet = netinfo_to_usernet(gnet[active_row].ni);
@@ -756,9 +768,9 @@ do_detect_cards()
 	{
 		struct ps_card *card = cards->data;
 		snprintf (cfg.device, 6, "%s", card->name);
-		for (acard = cards;acard;acard = g_slist_next(acard))
+		for (acard = cards; acard; acard=g_slist_next(acard))
 		{
-			card = cards->data;
+			card = acard->data;
 			cbDevice_items = g_list_append (cbDevice_items, card->name);
 		}
 		g_slist_free(cards);
@@ -793,7 +805,7 @@ on_fMain_show (GtkWidget * widget, gpointer user_data)
 {
 	GtkTextBuffer *log;
 
-	// we do the rest of initialisation here...
+	/* we do the rest of initialisation here... */
 	load_icons ();
 
 	if (init_db() < 0)
@@ -816,6 +828,9 @@ on_fMain_show (GtkWidget * widget, gpointer user_data)
 	case DT_HOSTAP:
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rbDriverHA), TRUE);
 		break;
+	case DT_CISCO:
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rbDriverCI), TRUE);
+		break;
 #ifdef WLAN_NG
 	case DT_PRISM:
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rbDriverNG), TRUE);
@@ -840,34 +855,19 @@ on_fMain_show (GtkWidget * widget, gpointer user_data)
 	
 	send_config ();
 	if (!driver_set)
-		send_command (C_DETECT_CARD,0);
-
+	{
+		send_command (C_DETECT_CARD, 0);
+		send_command (C_DETECT_DHCP, 0);
+	}
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook1),0);
 	
-	// setup periodically update
+	gui_update_busy = FALSE;
+	
+	/* setup periodically update */
 	gtk_timeout_add (UPDATE_INTERVAL, (GtkFunction) do_timer_update, NULL);
 }
 
 
-/*
-void
-on_tree_select_row (GtkTreeView * treeview,
-		    GtkTreePath * arg1,
-		    GtkTreeViewColumn * arg2, gpointer user_data)
-{
-	GtkTreeSelection *selection;
-	GtkTreeIter iter;
-	int nnode;
-	
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
-	gtk_tree_selection_get_selected (selection, NULL, &iter);
-	gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, COL_DATA, &nnode, -1);
-	selected_net = nnode->ni;
-	
-}
-*/
-
-
 void
 on_notebook1_switch_page (GtkNotebook * notebook,
 			  GtkNotebookPage * page,
@@ -889,7 +889,7 @@ on_gclWlans_button_press_event (GtkWidget * widget,
 {
 	GtkMenu *menu;
 	GdkEventButton *event_button;
-
+	
 	menu = GTK_MENU (create_menu1 ());
 	if (event->type == GDK_BUTTON_PRESS)
 	{
@@ -914,22 +914,20 @@ on_gclWlans_button_press_event (GtkWidget * widget,
 void
 on_delete1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-/*	gchar *dbssid;
-	gchar *dchan;
+	int i;
 
 	if (active_row >= 0)
 	{
-		gtk_clist_get_text (gclWlans, active_row, 2, &dbssid);
-		gtk_clist_get_text (gclWlans, active_row, 1, &dchan);
-		if (!deletenetwork (dbssid, atoi (dchan)))
+		if (!deletenetwork (gnet[active_row].ni->bssid, gnet[active_row].ni->channel))
 		{
-			free (gtk_clist_get_row_data (gclWlans, active_row));
-			gtk_clist_remove (gclWlans, active_row);
+			gtk_tree_store_remove (store, &gnet[active_row].iter);
+			g_free(gnet[active_row].ni);
+			for (i = active_row; i < actual_rows; i++)
+				gnet[i] = gnet[i+1];
 			actual_rows--;
 			active_row = -1;
 		}
 	}
-*/	
 }
 
 
@@ -940,17 +938,6 @@ on_view_detail1_activate (GtkMenuItem * menuitem, gpointer user_data)
 }
 
 
-void
-on_gclWlans_unselect_row (GtkCList * clist,
-			  gint row,
-			  gint column, GdkEvent * event, gpointer user_data)
-{
-#warning update	
-	last_row = row;
-	active_row = -1;
-}
-
-
 void
 on_cbNight_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
@@ -1004,10 +991,7 @@ on_cbNight_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 		gtk_widget_modify_style (GTK_WIDGET (tree), rc_style);
 		gtk_widget_modify_style (GTK_WIDGET (gclDetail), rc_style);
 		gtk_widget_modify_style (GTK_WIDGET (txLog), rc_style);
-/*		gtk_widget_set_style(txLog,gtk_style_copy(gtk_widget_get_default_style ()));
-		gtk_widget_set_style(gclDetail,gtk_style_copy(gtk_widget_get_default_style ()));
-		gtk_widget_set_style(tree,gtk_style_copy(gtk_widget_get_default_style ()));
-*/	}
+	}
 	gtk_rc_style_unref(rc_style);
 	update_colors();
 }
@@ -1023,7 +1007,7 @@ on_fMain_key_press_event (GtkWidget * widget,
 		gtk_notebook_set_page (GTK_NOTEBOOK(notebook1), 1);
 		return TRUE;
 		break;
-	case GDK_l:
+	case GDK_b:
 		gtk_notebook_set_page (GTK_NOTEBOOK(notebook1), 0);
 		return TRUE;
 		break;
@@ -1060,7 +1044,7 @@ on_fMain_key_press_event (GtkWidget * widget,
 			return FALSE;
 		break;
 	}
-	return FALSE;
+	return TRUE;
 }
 
 
@@ -1130,6 +1114,8 @@ on_bStartScan_clicked (GtkButton * button, gpointer user_data)
 		cfg.devtype = DT_HOSTAP;
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rbDriverSC)))
 		cfg.devtype = DT_SCAN;
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rbDriverCI)))
+		cfg.devtype = DT_CISCO;
 
 	sprintf (logmessage, "Changed capture device to %s.\n", devname);
 	printlog (logmessage);
@@ -1151,14 +1137,18 @@ gboolean
 tv_row_clicked(GtkTreeView *treeview, GtkTreePath *arg1, 
 	GtkTreeViewColumn *arg2, gpointer user_data)
 {
-	GtkWidget *details;
 	int netpos;
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
 
 	selection = gtk_tree_view_get_selection (treeview);
 	if (gtk_tree_selection_get_selected (selection, NULL, &iter) == FALSE) 
+	{
+		/* nothing selected */
+		last_row = active_row;
+		active_row = -1;
 		return FALSE;
+	}
 	gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, COL_DATA, &netpos, -1);
 
 	last_row = active_row;
@@ -1167,6 +1157,7 @@ tv_row_clicked(GtkTreeView *treeview, GtkTreePath *arg1,
 	return TRUE;	
 }
 
+
 void
 update_gui_pos(int netpos)
 {
@@ -1398,8 +1389,7 @@ update_gui_pos(int netpos)
 		sprintf (tmpvec[1], "%s", selected_net->ipsec ? "yes" : "no");
 		gtk_clist_append (GTK_CLIST(gclDetail), tmpvec);
 
-		sscanf (selected_net->bssid, "%x:%x:%x", &b0, &b1,
-			&b2);
+		sscanf (selected_net->bssid, "%x:%x:%x", &b0, &b1, &b2);
 		strcpy (tmpvec[0], "Manufacturer");
 		binbssid[0] = b0;
 		binbssid[1] = b1;
@@ -1408,7 +1398,7 @@ update_gui_pos(int netpos)
 		gtk_clist_append (GTK_CLIST(gclDetail), tmpvec);
 
 		strcpy (tmpvec[0], "Protocols");
-		sprintf (tmpvec[1], "");
+		tmpvec[1][0] = 0;
 		for (b0 = 0; b0 < selected_net->pcount; b0++)
 			sprintf (tmpvec[1], "%s%i,", tmpvec[1],
 				 selected_net->pvec[b0]);
